import h2o_mlops_client as mlops

# Defines MLOps API URL. The address for the MLOps Gateway component.
# Usually: "https://api.mlops.my.domain"
MLOPS_API_URL = ""

# Defines IDP's token endpoint URL. For deployments using Keycloak as IDP:
# https://mlops.keycloak.domain/auth/realms/[fill-in-realm-name]/protocol/openid-connect/token
TOKEN_ENDPOINT_URL = ""

# Defines user's refresh token.
REFRESH_TOKEN = ""

# Sets client id for authentication.
CLIENT_ID = ""

# Sets client secret for authentication.
CLIENT_SECRET = ""

# Sets project id. 
PROJECT_ID = ""


# Count the registered models for a given project.
def count_registered_models(
        mlops_client: mlops.Client, 
        count_model_request: mlops.StorageCountRegisteredModelRequest
):
    return mlops_client.storage.registered_model.count_registered_models(count_model_request)


def get_count_registered_model_request(project_id):
    return mlops.StorageCountRegisteredModelRequest(project_id=project_id)


def main():
    # Set up the token provider using an existing refresh token.
    mlops_token_provider = mlops.TokenProvider(
        refresh_token=REFRESH_TOKEN,
        client_id=CLIENT_ID,
        client_secret=CLIENT_SECRET,
        token_endpoint_url=TOKEN_ENDPOINT_URL,
    )

    # Set up the MLOps client.
    mlops_client = mlops.Client(
        gateway_url=MLOPS_API_URL,
        token_provider=mlops_token_provider,
    )

    count_model_response: mlops.StorageCountRegisteredModelResponse = count_registered_models(
        mlops_client,
            get_count_registered_model_request(
                project_id=PROJECT_ID
            )
        )
    print(count_model_response)


if __name__ == "__main__":
    main()